Saxo.ReferenceData.Instruments (Saxo v0.2.0)

End points serving instrument resources.

Summary

Functions

Provides an overview of a contract futures space.

Use this operation to retrieve details for a specific instrument.

Use this operation to retrieve detailed information a list of instruments.

Get option details and options space for specified option root.

Search for instruments or contract option roots

Returns trading schedule for a given uic and asset type.

Functions

Link to this function

futures_space(credentials, params)

@spec futures_space(
  Saxo.Credentials.t(),
  keyword()
) :: map()

Provides an overview of a contract futures space.

Options:

  • :ContinuousFuturesUic (integer/0) - Required. The UIC of the continuous futures instrument of the space.
Link to this function

instrument(credentials, params)

@spec instrument(
  Saxo.Credentials.t(),
  keyword()
) :: map()

Use this operation to retrieve details for a specific instrument.

Options:

  • :"$skip" (integer/0)

  • :"$top" (integer/0)

  • :AssetType - Required. The type of the instrument to get, one of the following [:Bond, :Cash, :ContractFutures, :Etf, :FuturesOption, :FxForwards, :FxSpot, :FxSwap]

  • :Uic (integer/0) - Required. The Universal Instrument Code (UIC) of the instrument to get

  • :FieldGroups - Comma separated list of the following options: :SupportedOrderTypeSettings, :OrderSetting, :TradingSessions, :MarketData

  • :AccountKey (String.t/0) - If specified, access permissions to instruments for the specified account will be evaluated

  • :ClientKey (String.t/0)

Link to this function

instruments(credentials, params)

@spec instruments(
  Saxo.Credentials.t(),
  keyword()
) :: map()

Use this operation to retrieve detailed information a list of instruments.

Options:

  • :AccountKey (String.t/0) - If specified, access permissions to instruments for the specified account will be evaluated

  • :AssetTypes (String.t/0) - Comma separated list of one or more asset types to search for. E.g. AssetTypes=FxSpot,Stock

  • :FieldGroups - Comma separated list of the following options: :SupportedOrderTypeSettings, :OrderSetting, :TradingSessions, :MarketData

  • :Tags (String.t/0)

  • :Uics (String.t/0) - Limit list to return information for the following comma separated Uics

Link to this function

options_space(credentials, params)

@spec options_space(
  Saxo.Credentials.t(),
  keyword()
) :: map()

Get option details and options space for specified option root.

Options:

  • :OptionRootId (integer/0) - Required. ID of the contract option root.

  • :CanParticipateInMultiLegOrder (boolean/0)

  • :ClientKey (String.t/0)

  • :ExpiryDates (String.t/0) - Return specific information for the ExpiryDates in this array

  • :OptionSpaceSegment - Specify how large a segment of the complete option space to return

  • :TradingStatus - Trading status of an instrument

  • :UnderlyingUic (integer/0) - The uic of the underlying instrument.

Link to this function

search(credentials, params)

@spec search(
  Saxo.Credentials.t(),
  keyword()
) :: map()

Search for instruments or contract option roots

Options:

  • :"$skip" (integer/0)

  • :"$top" (integer/0)

  • :AccountKey (String.t/0) - If specified, access permissions to instruments for the specified account will be evaluated

  • :AssetTypes (String.t/0) - Comma separated list of one or more asset types to search for. E.g. AssetTypes=FxSpot,Stock

  • :CanParticipateInMultiLegOrder (boolean/0)

  • :Class

  • :ExchangeId (String.t/0) - ID of the exchange that the instruments must match.

  • :IncludeNonTradable (boolean/0)

  • :Keywords (String.t/0) - Search for matching keywords in the instruments. Separate keywords with spaces.

  • :Tags (String.t/0)

  • :Uics (String.t/0) - Limit list to return information for the following comma separated Uics

Link to this function

trading_schedules(credentials, params)

@spec trading_schedules(
  Saxo.Credentials.t(),
  keyword()
) :: map()

Returns trading schedule for a given uic and asset type.

Options:

  • :AssetType - Required. The type of the instrument to get, one of the following [:Bond, :Cash, :ContractFutures, :Etf, :FuturesOption, :FxForwards, :FxSpot, :FxSwap]

  • :Uic (integer/0) - Required. The Universal Instrument Code (UIC) of the instrument to get